==> iql-1.8.5.tar.gz: iql-1.8.5/iql/extensions/cache_extension.py <==
import logging
from typing import Optional
import pandas as pd
import json

from dataclasses import dataclass

from ..ql import register_extension, executedf
from ..constants import get_cache
from ..datamodel.extension import IqlExtension
from ..datamodel.subquery import SubQuery

logger = logging.getLogger(__name__)


@dataclass
class CacheClearAll(IqlExtension):
    """Clears the entire cache"""

    keyword: str

    def executeimpl(self, sq: SubQuery) -> pd.DataFrame:
        get_cache().clear_all()

        return pd.DataFrame([{"result:": True}])


@dataclass
class CacheClear(IqlExtension):
    """Clears a single item from the cache"""

    keyword: str

    def executeimpl(self, sq: SubQuery) -> pd.DataFrame:
        assert "key" in sq.options
        key: str = sq.options["key"]  # type: ignore

        prefix: str = sq.options.get("prefix", "default")  # type: ignore
        get_cache().clear(key, prefix)

        return pd.DataFrame([{"result:": True}])


@dataclass
class CacheGet(IqlExtension):
    """Gets a single item from the cache"""

    keyword: str

    def executeimpl(self, sq: SubQuery) -> pd.DataFrame:
        prefix = sq.options.get("prefix", "default")
        policy = json.loads(sq.options["policy"]) if "policy" in sq.options else None  # type: ignore

        assert "key" in sq.options

        cached_df: pd.DataFrame = get_cache().get(sq.options["key"], prefix, policy)  # type: ignore
        return cached_df


@dataclass
class CachePut(IqlExtension):
    """Clears a single item from the cache"""

    keyword: str

    def executeimpl(self, sq: SubQuery) -> pd.DataFrame:
        prefix = "default"
        data: Optional[pd.DataFrame] = None
        assert "query" in sq.options and "key" in sq.options

        if "prefix" in sq.options:
            prefix = sq.options["prefix"]
        if "query" in sq.options:
            assert sq.iqc.db is not None
            base_connection = sq.iqc.db.get_connection()
            data = executedf(sq.options["query"], base_connection)
        if "policy" in sq.options:
            policy = json.loads(sq.options["policy"])  # type: ignore
        else:
            policy = None

        get_cache().save(sq.options["key"], data, prefix, policy)  # type: ignore
        return pd.DataFrame([{"result:": True}])


def register(keyword):
    register_extension(CacheClearAll(keyword=keyword, subword="clear_all"))
    register_extension(CacheClear(keyword=keyword, subword="clear"))
    register_extension(CacheGet(keyword=keyword, subword="get"))
    register_extension(CachePut(keyword=keyword, subword="put"))

==> iql-1.8.8.tar.gz: iql-1.8.8/iql/extensions/cache_extension.py <==
import json
import logging
from dataclasses import dataclass
from typing import Optional

import pandas as pd

from ..constants import get_cache
from ..datamodel.extension import IqlExtension
from ..datamodel.subquery import SubQuery
from ..ql import register_extension

logger = logging.getLogger(__name__)


@dataclass
class CacheClearAll(IqlExtension):
    """Clears the entire cache"""

    keyword: str

    def executeimpl(self, sq: SubQuery) -> pd.DataFrame:
        get_cache().clear_all()

        return pd.DataFrame([{"result:": True}])


@dataclass
class CacheClear(IqlExtension):
    """Clears a single item from the cache"""

    keyword: str

    def executeimpl(self, sq: SubQuery) -> pd.DataFrame:
        key: str = sq.options["key"]  # type: ignore

        prefix: str = sq.options.get("prefix", "default")  # type: ignore
        get_cache().clear(key, prefix)

        return pd.DataFrame([{"result:": True}])


@dataclass
class CacheGet(IqlExtension):
    """Gets a single item from the cache"""

    keyword: str

    def executeimpl(self, sq: SubQuery) -> pd.DataFrame:
        key = sq.options["key"]
        prefix = sq.options.get("prefix", "default")
        policy = json.loads(sq.options["policy"]) if "policy" in sq.options else None  # type: ignore

        cached_df: pd.DataFrame = get_cache().get(key, prefix, policy)  # type: ignore
        return cached_df


@dataclass
class CachePut(IqlExtension):
    """Clears a single item from the cache"""

    keyword: str

    def executeimpl(self, sq: SubQuery) -> pd.DataFrame:
        prefix = "default"
        data: Optional[pd.DataFrame] = None

        query = sq.options["query"]
        key = sq.options["key"]

        if "prefix" in sq.options:
            prefix = sq.options["prefix"]

        data = sq.iqc.db.execute_query(query)

        if "policy" in sq.options:
            policy = json.loads(sq.options["policy"])  # type: ignore
        else:
            policy = None

        get_cache().save(key, data, prefix, policy)  # type: ignore
        return pd.DataFrame([{"result:": True}])


def register(keyword):
    register_extension(CacheClearAll(keyword=keyword, subword="clear_all"))
    register_extension(CacheClear(keyword=keyword, subword="clear"))
    register_extension(CacheGet(keyword=keyword, subword="get"))
    register_extension(CachePut(keyword=keyword, subword="put"))
